==> gatherer-2.99.0.0372.zip: Gatherer/GatherEvent.lua <==
--[[
	Gatherer Addon for World of Warcraft(tm).
	Version: 2.99.0.0372 (eagle)
	Revision: $Id: GatherEvent.lua 366 2006-12-24 07:08:26Z esamynn $

	License:
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program(see GPL.txt); if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

	Note:
		This AddOn's source code is specifically designed to work with
		World of Warcraft's interpreted AddOn system.
		You have an implicit licence to use this AddOn with these facilities
		since that is it's designated purpose as per:
		http://www.fsf.org/licensing/licenses/gpl-faq.html#InterpreterIncompat

	Event handling routines
]]
local _tr = Gatherer.Locale.Tr
local _trC = Gatherer.Locale.TrClient
local _trL = Gatherer.Locale.TrLocale

-- reference to the Astrolabe mapping library
local Astrolabe = AceLibrary:GetInstance(Gatherer.AstrolabeVersion)

function Gatherer.Event.OnLoad()
	this:RegisterEvent("WORLD_MAP_UPDATE")
	this:RegisterEvent("CLOSE_WORLD_MAP"); -- never triggered apparently
	this:RegisterEvent("LEARNED_SPELL_IN_TAB"); -- follow current skills
	this:RegisterEvent("SPELLS_CHANGED"); -- follow current skills
	this:RegisterEvent("SKILL_LINES_CHANGED"); -- follow current skills
	this:RegisterEvent("UI_ERROR_MESSAGE"); -- track failed gathering

	-- Events for off world non processing
	this:RegisterEvent("PLAYER_ENTERING_WORLD")
	this:RegisterEvent("PLAYER_LEAVING_WORLD")

	-- Addon Loaded and player login/logout events
	this:RegisterEvent("ADDON_LOADED")
	this:RegisterEvent("PLAYER_LOGIN")
	this:RegisterEvent("PLAYER_LOGOUT")

	-- Communications
	this:RegisterEvent("CHAT_MSG_ADDON")

	SLASH_GATHER1 = "/gather"
	SLASH_GATHER2 = "/gatherer"
	SlashCmdList["GATHER"] = function(msg)
		Gatherer.Command.Process(msg)
	end

	LibSwag.RegisterHook("Gatherer", Gatherer.Event.OnSwag)
end

local lastMessage = ""
function Gatherer.Event.OnEvent( event, ... )
	-- Enable/Disable event processing for zoning
	if (event == "PLAYER_ENTERING_WORLD" ) then
		GatherNoteUpdateFrame:Show()

	elseif (event == "PLAYER_LEAVING_WORLD" ) then
		GatherNoteUpdateFrame:Hide()

	elseif (event == "WORLD_MAP_UPDATE") then
		if (WorldMapFrame:IsVisible()) then
			Gatherer.Mapping.MapDraw()
		elseif (Gatherer.Var.MapOpen) then
			Gatherer.Mapping.MapDraw()
		end
	elseif ( event == "CLOSE_WORLD_MAP") then
		Gatherer.Mapping.MapDraw()

	elseif( event == "ADDON_LOADED" ) then
		local addon = select(1, ...)
		if (addon and string.lower(addon) == "gatherer") then
			--[[
			if ( myAddOnsFrame_Register ) then
				-- myAddons Support
				GathererDetails["name"] = "Gatherer"
				GathererDetails["version"] = GATHERER_VERSION
				GathererDetails["author"] = "Norganna"
				GathererDetails["website"] = "http://gathereraddon.com"
				GathererDetails["category"] = MYADDONS_CATEGORY_PROFESSIONS
				GathererDetails["frame"] = "Gatherer"
				GathererDetails["optionsframe"] = "Gatherer.Interface.DialogFrame"
				
				-- Register the addon in myAddOns
				if(myAddOnsFrame_Register) then
					myAddOnsFrame_Register(GathererDetails, GathererHelp)
				end
			end
			--]]
			
			LibSwag.Init()
			
			Gatherer.Config.Load()
			Gatherer.Var.Loaded = true
			Gatherer.Event.OnUpdate(0, true)
			
			Gatherer.Util.Print("Gatherer v"..Gatherer.Var.Version.." -- Loaded!")
			
			if (Gatherer.Settings.useMainmap == true) then
				Gatherer_WorldMapDisplay:SetText("Hide Items")
			else
				Gatherer_WorldMapDisplay:SetText("Show Items")
			end
			
			-- record current version number in order to identify the data for backup utilities
			Gatherer.Settings.Version = GATHERER_VERSION
			
			-- Get values for World Map once for all
			Gatherer.Var.WmWidth = WorldMapDetailFrame:GetWidth()
			Gatherer.Var.WmHeight = WorldMapDetailFrame:GetHeight()
			Gatherer.Var.WmLevel = WorldMapPlayer:GetFrameLevel()
		end
	elseif ( event == "PLAYER_LOGIN" ) then
		local SETTINGS = Gatherer.Settings
		local useMinimap = (SETTINGS.useMinimap) and "On" or "Off"
		local useMainmap = (SETTINGS.useMainmap) and "On" or "Off"
		local mapMinder = (SETTINGS.mapMinder) and "On" or "Off"
		local minderTime = (SETTINGS.minderTime or 0).."s"

		if ( SETTINGS.logInfo and SETTINGS.logInfo == "on" ) then
			Gatherer.Util.Print("[Player: "..Gatherer.Var.PlayerName..", Theme: "..SETTINGS.iconSet..", Mainmap: "..useMainmap..", Minimap: "..useMinimap..", MaxDist: "..SETTINGS.maxDist.." units, NoteCount: "..SETTINGS.number..", Fade: "..SETTINGS.fadePerc.."% at "..SETTINGS.fadeDist.." units, IconDist: "..SETTINGS.miniIconDist.."px on minimap, MapMinder: "..mapMinder.." ("..minderTime.."), Filters: herbs="..Gatherer.Command.GetFilterVal("herbs")..", mining="..Gatherer.Command.GetFilterVal("mining")..", treasure="..Gatherer.Command.GetFilterVal("treasure").."]")
		end

	elseif ( event == "PLAYER_LOGOUT" ) then
		Gatherer.Config.Save()

	elseif ( event == "LEARNED_SPELL_IN_TAB" or event == "SPELLS_CHANGED" ) then
		local numSkills = tonumber(GetNumSkillLines())
		if ( GetNumSkillLines() > 0 ) then
			Gatherer.Util.GetSkills()
		end
	elseif ( event == "SKILL_LINES_CHANGED" ) then
		local numSkills = tonumber(GetNumSkillLines())
		if ( GetNumSkillLines() > 0 ) then
			Gatherer.Util.GetSkills()
		end
	elseif ( event == "CHAT_MSG_ADDON" ) then
		local prefix, message, how, who = select(1, ...)
		if (prefix == "GathX" and message ~= lastMessage and who ~= UnitName("player")) then
			lastMessage = message
			local objectID, gatherC, zoneToken, gatherX, gatherY, loot = strsplit(";", message)
			objectID = tonumber(objectID)
			gatherC = tonumber(gatherC)
			gatherX = tonumber(gatherX)
			gatherY = tonumber(gatherY)
			if (objectID and gatherC and gatherX and gatherY) then
				local gatherZ = Gatherer.ZoneTokens.GetZoneIndex(gatherC, zoneToken)
				local gatherType = Gatherer.Nodes.Objects[objectID]

				if (gatherType) then
					local coins, loots = Gatherer.Util.LootSplit(loot)
					Gatherer.Api.AddGather(objectID, gatherType, "", who, coins, loots, false, gatherC, gatherZ, gatherX, gatherY)
					local objName = Gatherer.Util.GetNodeName(objectID);
					Gatherer.Util.ChatPrint(_tr("Received gather of %1 from %2 (%3)", objName, who, _tr(how:lower())))
				end
			end
		end
	elseif ( event == "UI_ERROR_MESSAGE" ) then
		local message =  select(1, ...)
		local skill = Gatherer.Util.ParseFormattedMessage(ERR_USE_LOCKED_WITH_ITEM_S, message)
		if (not skill) then
			skill = Gatherer.Util.ParseFormattedMessage(ERR_USE_LOCKED_WITH_SPELL_KNOWN_SI, message)
		end

		-- Check if there was a skill mentioned, then check to see if we're moused over a valid object
		if (skill) then
			LibSwag.SetTooltip()
			local tooltip = LibSwag.GetLastTip()
			local tip = tooltip.tip

			local objId = Gatherer.Nodes.Names[tip]
			if (objId) then
				-- We have a mouseover on a valid object that's just fired off
				-- a "Requires" message.
				local gType = Gatherer.Nodes.Objects[objId]
				Gatherer.Api.AddGather(objId, gType, tip, "require", 0, {}, false)
			end
		end
	elseif ( event ) then
		Gatherer.Util.ChatPrint("Gatherer Unknown event: "..event)
	end
end

function Gatherer.Event.OnUpdate(timeDelta, force)
	if (not Gatherer.Var.Loaded) then
		Gatherer.Util.Print("Gatherer not loaded")
		return
	end

	local SETTINGS = Gatherer.Settings

	local needsUpdate = false
	if (not GatherNotes) then
		GatherNotes = { timeDiff=0, checkDiff=0 }
		needsUpdate = true
	else
		GatherNotes.timeDiff = GatherNotes.timeDiff + timeDelta
		if (GatherNotes.timeDiff > Gatherer.Var.NoteUpdateInterval * 10) then
			needsUpdate = true
		end
	end
	if (force) then
		needsUpdate = true
		recalculate = true
	end

	if (needsUpdate) then
		local now = time()
		
		local c, z, px, py = Astrolabe:GetCurrentPlayerPosition()

		if not ( c and z and px and py ) then return end

		local displayNumber = SETTINGS.number
		local maxDist = SETTINGS.maxDist
		maxDist = 1000

		local curPos = 0
		for i, nodeC,nodeZ, nodeID, nodePos, nodeDist, nodeX,nodeY, nodeCount, gtype, nodeHarvested, nodeInspected, nodeSource
		 in Gatherer.Storage.ClosestNodesInfo(c, z, px, py, displayNumber, maxDist, Gatherer.Config.ShowOnMainMap) do
			curPos = curPos + 1
			if (curPos > SETTINGS.number) then break end

			-- need to position and label the corresponding button
			local gatherNote = getglobal("GatherNote"..curPos)
			local gatherNoteTexture = getglobal("GatherNote"..curPos.."Texture")
			Astrolabe:PlaceIconOnMinimap(gatherNote, nodeC, nodeZ, nodeX, nodeY)

			local fadeDist = SETTINGS.fadeDist
			local fadePerc = SETTINGS.fadePerc / 100
			local tracDist = SETTINGS.tracDist or 100
			local opacity = (SETTINGS.alpha or 80) / 100
			
			local iconColor = "normal"

			--TODO Make these proper settings
			local tracDist = 110
			local fadeDist = 500
			local fadePerc = 0.2
			local inspDist = 20
			local inspPerc = 0.2
			local inspTime = 120
			local anonPerc = 0.6
			local opacity = 0.8
			
			local selectedTexture, trimTexture = Gatherer.Util.GetNodeTexture(nodeID)

			-- If this icon has not been verified
			if (nodeSource and nodeSource ~= 'require') then
				opacity = anonPerc
				iconColor = "red"
			end

			-- If node is within tracking distance
			if (nodeDist < tracDist) then
				if (Gatherer.Util.GetTrackingMode() == Gatherer.Nodes.Objects[nodeID]) then
					selectedTexture = "Interface\\AddOns\\Gatherer\\Shaded\\White"
					trimTexture = false
				end
			end

			-- If we need to fade the icon (because of great distance
			if (fadeDist > 0 and fadePerc > 0 and nodeDist > tracDist) then
				local range = math.max(fadeDist - tracDist, 0)
				local posit = math.min(nodeDist - tracDist, range)
				if (range > 0) then
					local ratio = posit / range
					local fadeLevel = (opacity - fadePerc) * ratio
					opacity = opacity - fadeLevel
				end
			end

			-- If we are within 35 yards of this item, mark it as inspected
			if (nodeDist < inspDist) then
				Gatherer.Storage.SetNodeInspected(nodeC, nodeZ, nodeID, nodePos)
				iconColor = "green"
				opacity = 1

			-- If we've recently seen this node, set its transparency
			elseif (nodeInspected and inspTime > 0 and now - nodeInspected < inspTime) then
				local posit = math.max(now - nodeInspected, 0)
				local ratio = 1 - (posit / inspTime)
				local fadeLevel = (opacity - inspPerc) * ratio
				opacity = opacity - fadeLevel
			end

			-- Set the texture
			gatherNoteTexture:SetTexture(selectedTexture)

			-- Check to see if we need to trim the border off
			if (trimTexture) then
				gatherNoteTexture:SetTexCoord(0.08,0.92,0.08,0.92)
			else
				gatherNoteTexture:SetTexCoord(0,1,0,1)
			end

			-- Put the frame at the right level
			gatherNote:SetFrameLevel(MiniMapTrackingFrame:GetFrameLevel()-1)

			-- If this node is unverified, then make it reddish
			if (iconColor == "red") then
				gatherNoteTexture:SetVertexColor(0.9,0.4,0.4)
			elseif (iconColor == "green") then
				gatherNoteTexture:SetVertexColor(0.4,0.9,0.4)
			elseif (iconColor == "blue") then
				gatherNoteTexture:SetVertexColor(0.4,0.4,0.9)
			else
				gatherNoteTexture:SetVertexColor(1,1,1)
			end
			gatherNoteTexture:SetAlpha(opacity)

			if (not gatherNote.obj) then gatherNote.obj = {} end
			gatherNote.obj.id = nodeID
			gatherNote.obj.count = nodeCount
			gatherNote.obj.who = nodeSource
			gatherNote.obj.last = nodeInspected or nodeHarvested
			gatherNote.obj.dist = nodeDist

--[[
			-- Added to allow hiding if under min distance
			if ( SETTINGS.NoIconOnMinDist ~= nil and SETTINGS.NoIconOnMinDist == 1 ) then
				if ( gDist < (math.floor(sDist)-1) ) then
					gatherNote:Hide()
				else
					gatherNote:Show()
				end
			elseif ( (not SETTINGS.NoIconOnMinDist or SETTINGS.NoIconOnMinDist == 0) and SETTINGS.alphaUnderMinIcon and gDist < (math.floor(sDist)-1) ) then
				if ( SETTINGS.iconSet and SETTINGS.iconSet ~= "iconshade" ) then
					gatherNote:SetAlpha(SETTINGS.alphaUnderMinIcon / 100)
				end
				gatherNote:Show()
			else
				gatherNote:Show()
			end
--]]
		end

		while (curPos < Gatherer.Var.MaxNumNotes) do
			curPos = curPos+1
			Astrolabe:RemoveIconFromMinimap(getglobal("GatherNote"..curPos));
		end
	end
end

function Gatherer.Event.OnSwag(lootType, lootTable, coinAmount, extraData)
	if (lootType ~= "KILL") then
		local gatherType
		if (lootType == "MINE") then gatherType="Mine"
		elseif (lootType == "HERB") then gatherType="Herb"
		elseif (lootType == "SKIN") then gatherType="Skin"
		elseif (lootType == "FISH") then gatherType="Fish"
		elseif (lootType == "OPEN") then gatherType="Treasure"
		end

		local locale = GetLocale()

		local node = "Unknown"
		if (extraData and extraData.tip) then node = extraData.tip end
		local object = Gatherer.Nodes.Names[node]
		if (not object) then return end

		local objectType = Gatherer.Nodes.Objects[object]
		if (objectType ~= lootType) then return end

		Gatherer.Api.AddGather(object, gatherType, storagetip, nil, coinAmount, lootTable, true)
	end
end

-- Pass on any node clicks
function Gatherer.Event.MiniNoteOnClick()
	local x, y = GetCursorPosition()
	if ( Minimap.GetEffectiveScale ~= nil ) then
		x = x / Minimap:GetEffectiveScale()
		y = y / Minimap:GetEffectiveScale()
	else
		x = x / Minimap:GetScale()
		y = y / Minimap:GetScale()
	end

	local cx, cy = Minimap:GetCenter()
	x = x + CURSOR_OFFSET_X - cx
	y = y + CURSOR_OFFSET_Y - cy
	if ( sqrt(x * x + y * y) < (Minimap:GetWidth() / 2) ) then
		Minimap:PingLocation(x, y)
	end
end

function Gatherer.Event.MiniNoteOnEnter(frame)
	if (Gatherer.Settings and Gatherer.Settings.HideMiniNotes and Gatherer.Settings.HideMiniNotes == 1) then
		return
	end

	GameTooltip:SetOwner(this, "ANCHOR_BOTTOMLEFT")
	
	local id = frame.obj.id
	local name = Gatherer.Util.GetNodeName(id)
	local count = frame.obj.count
	local who = frame.obj.who
	local last = frame.obj.last
	local dist = frame.obj.dist

	GameTooltip:ClearLines()
	GameTooltip:AddLine(name)
	if (count > 0) then
		GameTooltip:AddLine(_tr("Gathered %1 times", count))
	end
	if (who) then
		if (who == "require") then
			GameTooltip:AddLine(_tr("Unskilled Gather"))
		else
			GameTooltip:AddLine(_tr("Source: %1", who))
		end
	end
	if (last and last > 0) then
		GameTooltip:AddLine(_tr("Last seen: %1s ago", time()-last))
	end
	GameTooltip:AddLine(_tr("Disance: %1 yards", dist))
	
	if (GatherDrops) then
		local drops = GatherDrops[id]
		if (drops) then
			local total = drops.total
			if (total and total > 0) then
				GameTooltip:AddLine(_tr("Overall drop rates:"))
				for item, count in pairs(drops) do
					if (item ~= "total") then
						local itemName, itemLink, itemRarity, itemLevel, itemMinLevel, itemType, itemSubType, itemStackCount, itemEquipLoc, invTexture = GetItemInfo(item) 
						
						if (itemName) then
							local expected = count/total
							if (expected > 0.01) then
								GameTooltip:AddDoubleLine(itemLink, string.format("x%0.2f", expected))
								GameTooltip:AddTexture(invTexture)
							end
						end
					end
				end
			end
		end
	end
	GameTooltip:Show()
end

==> gatherer-2.99.0.0394.zip: Gatherer/GatherEvent.lua <==
--[[
	Gatherer Addon for World of Warcraft(tm).
	Version: 2.99.0.0394 (eagle)
	Revision: $Id: GatherEvent.lua 388 2007-01-04 23:53:05Z norganna $

	License:
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program(see GPL.txt); if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

	Note:
		This AddOn's source code is specifically designed to work with
		World of Warcraft's interpreted AddOn system.
		You have an implicit licence to use this AddOn with these facilities
		since that is it's designated purpose as per:
		http://www.fsf.org/licensing/licenses/gpl-faq.html#InterpreterIncompat

	Event handling routines
]]
local _tr = Gatherer.Locale.Tr
local _trC = Gatherer.Locale.TrClient
local _trL = Gatherer.Locale.TrLocale

function Gatherer.Event.OnLoad()
	this:RegisterEvent("WORLD_MAP_UPDATE")
	this:RegisterEvent("CLOSE_WORLD_MAP"); -- never triggered apparently
	this:RegisterEvent("LEARNED_SPELL_IN_TAB"); -- follow current skills
	this:RegisterEvent("SPELLS_CHANGED"); -- follow current skills
	this:RegisterEvent("SKILL_LINES_CHANGED"); -- follow current skills
	this:RegisterEvent("UI_ERROR_MESSAGE"); -- track failed gathering

	-- Events for off world non processing
	this:RegisterEvent("PLAYER_ENTERING_WORLD")
	this:RegisterEvent("PLAYER_LEAVING_WORLD")

	-- Addon Loaded and player login/logout events
	this:RegisterEvent("ADDON_LOADED")
	this:RegisterEvent("PLAYER_LOGIN")
	this:RegisterEvent("PLAYER_LOGOUT")

	-- Communications
	this:RegisterEvent("CHAT_MSG_ADDON")

	SLASH_GATHER1 = "/gather"
	SLASH_GATHER2 = "/gatherer"
	SlashCmdList["GATHER"] = function(msg)
		Gatherer.Command.Process(msg)
	end

	LibSwag.RegisterHook("Gatherer", Gatherer.Event.OnSwag)
end

local lastMessage = ""
function Gatherer.Event.OnEvent( event, ... )
	-- Enable/Disable event processing for zoning
	if (event == "PLAYER_ENTERING_WORLD" ) then
		GatherNoteUpdateFrame:Show()

	elseif (event == "PLAYER_LEAVING_WORLD" ) then
		GatherNoteUpdateFrame:Hide()

	elseif (event == "WORLD_MAP_UPDATE") then
		if (WorldMapFrame:IsVisible()) then
			Gatherer.MapNotes.MapDraw()
		elseif (Gatherer.Var.MapOpen) then
			Gatherer.MapNotes.MapDraw()
		end
	elseif ( event == "CLOSE_WORLD_MAP") then
		Gatherer.MapNotes.MapDraw()

	elseif( event == "ADDON_LOADED" ) then
		local addon = select(1, ...)
		if (addon and string.lower(addon) == "gatherer") then
			--[[
			if ( myAddOnsFrame_Register ) then
				-- myAddons Support
				GathererDetails["name"] = "Gatherer"
				GathererDetails["version"] = GATHERER_VERSION
				GathererDetails["author"] = "Norganna"
				GathererDetails["website"] = "http://gathereraddon.com"
				GathererDetails["category"] = MYADDONS_CATEGORY_PROFESSIONS
				GathererDetails["frame"] = "Gatherer"
				GathererDetails["optionsframe"] = "Gatherer.Interface.DialogFrame"
				
				-- Register the addon in myAddOns
				if(myAddOnsFrame_Register) then
					myAddOnsFrame_Register(GathererDetails, GathererHelp)
				end
			end
			--]]
			
			LibSwag.Init()
			
			Gatherer.Config.Load()
			Gatherer.Var.Loaded = true
			Gatherer.MiniNotes.UpdateMinimapNotes(0, true)
			
			Gatherer.Util.Print("Gatherer v"..Gatherer.Var.Version.." -- Loaded!")
			
			if (Gatherer.Settings.useMainmap == true) then
				Gatherer_WorldMapDisplay:SetText("Hide Items")
			else
				Gatherer_WorldMapDisplay:SetText("Show Items")
			end
			
			-- record current version number in order to identify the data for backup utilities
			Gatherer.Settings.Version = GATHERER_VERSION
			
			-- Get values for World Map once for all
			Gatherer.Var.WmWidth = WorldMapDetailFrame:GetWidth()
			Gatherer.Var.WmHeight = WorldMapDetailFrame:GetHeight()
			Gatherer.Var.WmLevel = WorldMapPlayer:GetFrameLevel()
		end
	elseif ( event == "PLAYER_LOGIN" ) then
		local SETTINGS = Gatherer.Settings
		local useMinimap = (SETTINGS.useMinimap) and "On" or "Off"
		local useMainmap = (SETTINGS.useMainmap) and "On" or "Off"
		local mapMinder = (SETTINGS.mapMinder) and "On" or "Off"
		local minderTime = (SETTINGS.minderTime or 0).."s"

		if ( SETTINGS.logInfo and SETTINGS.logInfo == "on" ) then
			Gatherer.Util.Print("[Player: "..Gatherer.Var.PlayerName..", Theme: "..SETTINGS.iconSet..", Mainmap: "..useMainmap..", Minimap: "..useMinimap..", MaxDist: "..SETTINGS.maxDist.." units, NoteCount: "..SETTINGS.number..", Fade: "..SETTINGS.fadePerc.."% at "..SETTINGS.fadeDist.." units, IconDist: "..SETTINGS.miniIconDist.."px on minimap, MapMinder: "..mapMinder.." ("..minderTime.."), Filters: herbs="..Gatherer.Command.GetFilterVal("herbs")..", mining="..Gatherer.Command.GetFilterVal("mining")..", treasure="..Gatherer.Command.GetFilterVal("treasure").."]")
		end

	elseif ( event == "PLAYER_LOGOUT" ) then
		Gatherer.Config.Save()

	elseif ( event == "LEARNED_SPELL_IN_TAB" or event == "SPELLS_CHANGED" ) then
		local numSkills = tonumber(GetNumSkillLines())
		if ( GetNumSkillLines() > 0 ) then
			Gatherer.Util.GetSkills()
		end
	elseif ( event == "SKILL_LINES_CHANGED" ) then
		local numSkills = tonumber(GetNumSkillLines())
		if ( GetNumSkillLines() > 0 ) then
			Gatherer.Util.GetSkills()
		end
	elseif ( event == "CHAT_MSG_ADDON" ) then
		local prefix, message, how, who = select(1, ...)
		if (prefix == "GathX" and message ~= lastMessage and who ~= UnitName("player")) then
			lastMessage = message
			local objectID, gatherC, zoneToken, gatherX, gatherY, loot = strsplit(";", message)
			objectID = tonumber(objectID)
			gatherC = tonumber(gatherC)
			gatherX = tonumber(gatherX)
			gatherY = tonumber(gatherY)
			if (objectID and gatherC and gatherX and gatherY) then
				local gatherZ = Gatherer.ZoneTokens.GetZoneIndex(gatherC, zoneToken)
				local gatherType = Gatherer.Nodes.Objects[objectID]

				if (gatherType) then
					local coins, loots = Gatherer.Util.LootSplit(loot)
					Gatherer.Api.AddGather(objectID, gatherType, "", who, coins, loots, false, gatherC, gatherZ, gatherX, gatherY)
					local objName = Gatherer.Util.GetNodeName(objectID);
					Gatherer.Util.ChatPrint(_tr("Received gather of %1 from %2 (%3)", objName, who, _tr(how:lower())))
				end
			end
		end
	elseif ( event == "UI_ERROR_MESSAGE" ) then
		local message =  select(1, ...)
		local skill = Gatherer.Util.ParseFormattedMessage(ERR_USE_LOCKED_WITH_ITEM_S, message)
		if (not skill) then
			skill = Gatherer.Util.ParseFormattedMessage(ERR_USE_LOCKED_WITH_SPELL_KNOWN_SI, message)
		end

		-- Check if there was a skill mentioned, then check to see if we're moused over a valid object
		if (skill) then
			LibSwag.SetTooltip()
			local tooltip = LibSwag.GetLastTip()
			if (not tooltip) then return end
			local tip = tooltip.tip

			local objId = Gatherer.Nodes.Names[tip]
			if (objId) then
				-- We have a mouseover on a valid object that's just fired off
				-- a "Requires" message.
				local gType = Gatherer.Nodes.Objects[objId]
				Gatherer.Api.AddGather(objId, gType, tip, "REQUIRE", 0, {}, false)
			end
		end
	elseif ( event ) then
		Gatherer.Util.ChatPrint("Gatherer Unknown event: "..event)
	end
end

function Gatherer.Event.OnSwag(lootType, lootTable, coinAmount, extraData)
	if (lootType ~= "KILL") then
		local gatherType
		if (lootType == "MINE") then gatherType="Mine"
		elseif (lootType == "HERB") then gatherType="Herb"
		elseif (lootType == "SKIN") then gatherType="Skin"
		elseif (lootType == "FISH") then gatherType="Fish"
		elseif (lootType == "OPEN") then gatherType="Treasure"
		end

		local locale = GetLocale()

		local node = "Unknown"
		if (extraData and extraData.tip) then node = extraData.tip end
		local object = Gatherer.Nodes.Names[node]
		if (not object) then return end

		local objectType = Gatherer.Nodes.Objects[object]
		if (objectType ~= lootType) then return end

		Gatherer.Api.AddGather(object, gatherType, storagetip, nil, coinAmount, lootTable, true)
	end
end
